==> python-libdiscid_1.0.orig.tar.gz: python-libdiscid-1.0/libdiscid/discid.py <==
# -*- coding: utf-8 -*-

# Copyright 2013 Sebastian Ramacher <sebastian+dev@ramacher.at>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

""" Module to retain compatbility with the old interface.
"""

from libdiscid.exceptions import DiscError
from libdiscid._discid import DiscId
from libdiscid._discid import default_device
from libdiscid._discid import FEATURES_MAPPING, FEATURES
from libdiscid._discid import FEATURE_READ, FEATURE_MCN, FEATURE_ISRC
from libdiscid._discid import __discid_version__

import warnings
warnings.warn('libdiscid.discid is deprecated and should not be used in newly '
              'written code. It will be removed sometime in the future.',
              DeprecationWarning)

==> python-libdiscid_1.2.orig.tar.gz: python-libdiscid-1.2/libdiscid/discid.py <==
# Copyright 2013-2021 Sebastian Ramacher <sebastian+dev@ramacher.at>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""Module to retain compatibility with the old interface.
"""

from libdiscid.exceptions import DiscError
from libdiscid._discid import DiscId
from libdiscid._discid import default_device
from libdiscid._discid import FEATURES_MAPPING, FEATURES
from libdiscid._discid import FEATURE_READ, FEATURE_MCN, FEATURE_ISRC
from libdiscid._discid import __discid_version__

import warnings

warnings.warn(
    "libdiscid.discid is deprecated and should not be used in newly "
    "written code. It will be removed sometime in the future.",
    DeprecationWarning,
)
